# 3.0 Migration Guide

In this document we describe the steps that should be taken to migrate from `orchestrator-core` v2 to v3.

## About 3.0

In this release, deprecated import statements from the `orchestrator.types` module are removed, that now come from
`pydantic-forms.types` instead. These will have to be updated in your implementation of the orchestrator as well.

## Steps

To update the import statements you may have in your implementation of Workflow Orchestrator, we offer a migration
script that can be run as follows: `python -m orchestrator.devtools.scripts.migrate_30 <dir>` where `<dir>` points to
your orchestrator implementation.
